@@ -19,9 +19,25 @@
 #ifndef SCROLLKEEPER_H
 #define SCROLLKEEPER_H
 
+#include <libxml/tree.h>
+
 #define _(String) gettext (String)
 
+#define SCROLLKEEPERLOCALEDIR "/usr/share/locale"
+
+#define PATHLEN		256
+
 extern void sk_warning(int, char *, ...);
 extern void check_ptr(void *, char *);
+extern char **sk_get_language_list(void);
+extern int is_file(char *);
+extern int is_dir(char *);
+extern int apply_stylesheets(char *, char *, int, char **, char **);
+extern int copy_file(char *, char *);
+extern int install(char *, char *, char *, int);
+extern void create_database_directory(char *, char *);
+extern void uninstall(char *, char *, int);
+extern xmlDocPtr merge_locale_trees(char *, char *, char *);
+extern int update_doc_url_in_omf_file(char *, char *, char *);
 
 #endif /* SCROLLKEEPER_H */
